==> guikachu_1.0.1.orig.tar.gz: guikachu-1.0.1/src/form-editor/glyph.cc <==
//$Id: glyph.cc,v 1.2 2001/11/06 12:54:54 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#include "font.h"

#include <strstream>

using namespace Guikachu::GUI::FormEditor;

#define GLYPH_ON  '#'
#define GLYPH_OFF '-'

Glyph::Glyph (std::istream &stream,
	      unsigned int &height):
    width (0),
    offset (0),
    bitmap (0)
{
    
    std::string curr_line;
    bool        in_bitmap = true;
    bool        in_header = true;

    while (in_header)
    {
	getline (stream, curr_line);

	if (curr_line[0] == GLYPH_ON ||
	    curr_line[0] == GLYPH_OFF)
	{
	    in_header = false;
	    continue;
	}

	std::strstream curr_line_stream;
	std::string    param_name;
	int            param_val;
	
	curr_line_stream << curr_line;
	curr_line_stream >> param_name;
	curr_line_stream >> param_val;

	if (param_name == "OFFSET")
	    offset = param_val;
    }

    unsigned int row = 0;
    
    while (in_bitmap)
    {
	if (curr_line == "")
	{
	    in_bitmap = false;
	    continue;
	}

	if (!width)
	    width = curr_line.length ();

	bitmap = (bool**) realloc (bitmap, (row + 1) * sizeof (bool*));
	bitmap[row] = new bool[width];

	for (unsigned int i = 0; i < width; i++)
	    bitmap[row][i] = (curr_line[i] == GLYPH_ON) ? true : false;
	
	getline (stream, curr_line);
	row++;
    }

    if (!height)
	height = row;
}

==> guikachu_1.4.0.orig.tar.gz: guikachu-1.4.0/src/form-editor/glyph.cc <==
//$Id: glyph.cc,v 1.8 2003/06/30 14:07:57 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#include "font.h"

#include <sstream>

using namespace Guikachu::GUI::FormEditor;

#define GLYPH_ON  '#'
#define GLYPH_OFF '-'

Glyph::Glyph (int height, int ascent):
    width (5),
    bitmap (0)
{
    bitmap = new bool*[height];
    
    for (int i = 0; i < height; i++)
    {
	bitmap[i] = g_new0 (bool, width);
    }

    int y1 = ascent - 8;
    int y2 = ascent - 1;

    for (int x = 0; x < width; x++)
    {
	bitmap[y1][x] = true;
	bitmap[y2][x] = true;
    }

    for (int y = y1; y < y2; y++)
    {
	bitmap[y][0] = true;
	bitmap[y][4] = true;
    }
}

Glyph::Glyph (std::istream &stream,
	      int          &height):
    width (0),
    offset (0),
    bitmap (0)
{
    
    std::string curr_line;
    bool        in_bitmap = true;
    bool        in_header = true;

    while (in_header)
    {
	getline (stream, curr_line);

	if (curr_line[0] == GLYPH_ON ||
	    curr_line[0] == GLYPH_OFF)
	{
	    in_header = false;
	    continue;
	}

	std::stringstream curr_line_stream;
	std::string       param_name;
	int               param_val;
	
	curr_line_stream << curr_line;
	curr_line_stream >> param_name;
	if (!(curr_line_stream >> param_val))
	    param_val = 0;

	if (param_name == "OFFSET")
	    offset = param_val;
    }

    int row = 0;
    
    while (in_bitmap)
    {
	if (curr_line == "")
	{
	    in_bitmap = false;
	    continue;
	}

	if (!width)
	    width = curr_line.length ();

	bitmap = (bool**) realloc (bitmap, (row + 1) * sizeof (bool*));
	bitmap[row] = new bool[width];

	for (int i = 0; i < width; i++)
	    bitmap[row][i] = (curr_line[i] == GLYPH_ON) ? true : false;
	
	getline (stream, curr_line);
	row++;
    }

    if (!height)
	height = row;
}
